@@ -1,9 +1,16 @@
 #!/usr/bin/env python
-from gnip_rules import *
-from gnip_config import *
+# -*- coding: UTF-8 -*-
+from gnip_rules.gnip_rules import *
+from gnip_rules.gnip_config import *
 from optparse import OptionParser
+import fileinput
 import sys
 import json
+import codecs
+# unicode
+reload(sys)
+sys.stdout = codecs.getwriter('utf-8')(sys.stdout)
+
 
 parser = OptionParser()
 parser.add_option("-u", "--url", dest="url", default=None,
@@ -19,19 +26,19 @@ if options.url is not None:
 elif defaultUrl is not None:
     r = GnipRules(un, pwd, defaultUrl)
 else:
-    print "No url provided. Add [defaults] url=... to config file or use -u ..."
+    print >>sys.stderr, "No url provided. Add [defaults] url=... to config file or use -u ..."
     sys.exit()
 
 if options.delete:
     r.deleteGnipRules()
 
 if options.json:
-    buf = sys.stdin.read()
+    buf = ''.join([x for x in fileinput.FileInput(args,openhook=fileinput.hook_compressed)])
     r.initLocalRules()
     r.rulesList = json.loads(buf)["rules"]
 else:
     r.initLocalRules()
-    for row in sys.stdin:
+    for row in fileinput.FileInput(args,openhook=fileinput.hook_compressed):
         # rule \t tag
         rt = row.split('\t')
         if len(rt) == 2:
